@@ -29,12 +29,7 @@ pub struct Address {
     pub geo: Option<Geo>,
 }
 
-#[cfg_attr(
-    feature = "diesel",
-    derive(FromSqlRow, AsExpression),
-    sql_type = "diesel_mod::PgGeo"
-)]
-#[derive(PartialOrd, PartialEq, Clone, Debug)]
+#[derive(PartialOrd, PartialEq)]
 #[non_exhaustive]
 /// A simple structure to hold Geo location.
 pub struct Geo {
