@@ -1,4 +1,4 @@
-#[derive(Eq, PartialEq, Debug, Clone, Copy)]
+#[derive(Eq, PartialEq, Debug)]
 #[cfg_attr(
     feature = "diesel-derive-enum",
     derive(DbEnum),
