@@ -26,15 +26,13 @@ extern crate diesel_migrations;
 pub mod schema;
 
 #[cfg(feature = "diesel_support")]
-pub mod diesel_contact_information;
+pub mod diesel_support;
 
 #[cfg(feature = "diesel_support")]
 use schema::*;
 
 #[cfg(feature = "diesel_support")]
-pub mod diesel_contact;
-#[cfg(feature = "diesel_support")]
-pub(crate) use diesel_contact::DieselConversionError;
+pub(crate) use diesel_support::DieselConversionError;
 
 pub use {
     address::{Address, Geo},
@@ -138,46 +136,3 @@ impl std::convert::TryInto<vcard::vcard::VCard> for Contact {
         vcard::contack_to_vcard(&self)
     }
 }
-
-#[cfg(feature = "diesel_support")]
-/// This contact is a version of a contact which can be used with Diesel
-/// to create a new contact, insert it, and then update it. Once made you
-/// can convert it to a Contact with `.into();`
-#[derive(Insertable, Debug, Clone)]
-#[table_name="contacts"]
-pub struct NewContact {
-    pub uid: String,
-    pub name: name::Name,
-}
-
-#[cfg(feature = "diesel_support")]
-impl From<NewContact> for Contact {
-    fn from(them: NewContact) -> Contact {
-        Contact {
-            uid: them.uid,
-            name: them.name,
-            nickname: Default::default(),
-            anniversary: Default::default(),
-            bday: Default::default(),
-            photo: Default::default(),
-            title: Default::default(),
-            role: Default::default(),
-            org: Default::default(),
-            logo: Default::default(),
-            contact_information: Default::default(),
-            work_address: Default::default(),
-            home_address: Default::default(),
-        }
-    }
-}
-
-#[cfg(feature = "diesel_support")]
-impl NewContact {
-    #[must_use]
-    pub fn new(name: name::Name) -> Self {
-        Self {
-            name,
-            uid: uuid::Uuid::new_v4().to_string(),
-        }
-    }
-}
