@@ -1,9 +1,4 @@
-#[cfg_attr(
-    feature = "diesel",
-    derive(FromSqlRow, AsExpression),
-    sql_type = "diesel_mod::PgOrg"
-)]
-#[derive(Eq, PartialEq, Hash, Debug, Clone)]
+#[derive(Eq, PartialEq, Hash)]
 pub struct Org {
     pub org: String,
     pub unit: String,
